The Python file in this directory is an example of a custom MetadataJSONReproducer used in the tutorial for how to extract metadata from data files uploaded to a topic and produce those metadata as json-formatted strings to another topic. You can find the tutorial that uses that code (and the configuration file in this directory) in the documentation [here](https://openmsistream.readthedocs.io/en/latest/introduction/tutorials/extracting_metadata.html).